:import("path/library.css") {
  i__imported_importName_0: importName;
  i__imported_importName2_1: importName2;
}
:local(.exportName) {
  composes: i__imported_importName_0;
  composes: i__imported_importName2_1;
  composes: i__imported_importName_0 i__imported_importName2_1;
  other: rule;
}
