:import("path/library.css") {
  i__imported_importName_0: importName;
  i__imported_secondImport_1: secondImport;
  i__imported_importName2_3: importName2;
}
:import("path/library2.css") {
  i__imported_importName_2: importName;
}
:import("path/dep3.css") {
  i__imported_thirdDep_4: thirdDep;
}
:local(.exportName) {
  composes: i__imported_importName_0 i__imported_secondImport_1;
  composes: i__imported_importName_2;
  composes: i__imported_importName2_3;
}
:local(.exportName2) {
  composes: i__imported_secondImport_1;
  composes: i__imported_secondImport_1;
  composes: i__imported_thirdDep_4;
}
