:import("path/library.css") {
  i__imported_importName_0: importName;
  i__imported_secondImport_1: secondImport;
}
:local(.exportName) { composes: i__imported_importName_0 i__imported_secondImport_1; other: rule; }
