:import("path/library.css") {
  i__imported_importName_0: importName;
  i__imported_secondImport_1: secondImport;
  i__imported_thirdImport_2: thirdImport;
}
:import("path/other-lib.css") {
  i__imported_otherLibImport_3: otherLibImport;
}
:local(.exportName) {
  composes: i__imported_importName_0 i__imported_secondImport_1;
  other: rule;
}
:local(.otherExport) {
  composes: i__imported_thirdImport_2;
  composes: i__imported_otherLibImport_3;
}
